local require = GLOBAL.require
if GLOBAL.TheSim.RAILGetPlatform and GLOBAL.TheSim:RAILGetPlatform() == "TGP" then
    for _, mod in ipairs(GLOBAL.ModManager.mods) do
        if mod and mod.modinfo and mod.modinfo.id == "Devil Cuisine" then
            GLOBAL.KnownModIndex:Disable("Devil Cuisine")
        end
    end

    GLOBAL.Shutdown()
end

modimport("scripts/cookpotfix.lua")

Assets = {
    Asset("IMAGE", "images/inventoryimages/monster_meatballs.tex"),
    Asset("ATLAS", "images/inventoryimages/monster_meatballs.xml"),

    Asset("IMAGE", "images/inventoryimages/monster_meaty_stew.tex"),
    Asset("ATLAS", "images/inventoryimages/monster_meaty_stew.xml"),

    Asset("IMAGE", "images/inventoryimages/devil_pierogi.tex"),
    Asset("ATLAS", "images/inventoryimages/devil_pierogi.xml"),

    Asset("IMAGE", "images/inventoryimages/monster_kabobs.tex"),
    Asset("ATLAS", "images/inventoryimages/monster_kabobs.xml"),

    Asset("IMAGE", "images/inventoryimages/monster_chili.tex"),
    Asset("ATLAS", "images/inventoryimages/monster_chili.xml"),

    Asset("IMAGE", "images/inventoryimages/blackhoney_nuggets.tex"),
    Asset("ATLAS", "images/inventoryimages/blackhoney_nuggets.xml"),

    Asset("IMAGE", "images/inventoryimages/honey_monster_ham.tex"),
    Asset("ATLAS", "images/inventoryimages/honey_monster_ham.xml"),

    Asset("IMAGE", "images/inventoryimages/cobra_water.tex"),
    Asset("ATLAS", "images/inventoryimages/cobra_water.xml"),

    Asset("IMAGE", "images/inventoryimages/surstromming.tex"),
    Asset("ATLAS", "images/inventoryimages/surstromming.xml"),

    Asset("IMAGE", "images/inventoryimages/surstromming_bomb.tex"),
    Asset("ATLAS", "images/inventoryimages/surstromming_bomb.xml"),
}

PrefabFiles = {
    "monster_meatballs",
    "monster_meaty_stew",
    "devil_pierogi",
    "monster_kabobs",
    "monster_chili",
    "blackhoney_nuggets",
    "honey_monster_ham",
    "cobra_water",
    "surstromming",
    "surstromming_bomb",
}

local monster_meatballs_recipe = {
    name = "monster_meatballs",
    test = function(cooker, names, tags) return tags.monster == 1 and not tags.inedible end,
    priority = 1,
    weight = 1,
    foodtype = "MEAT",
    health = -10,
    hunger = 58,
    perishtime = TUNING.PERISH_MED,
    sanity = -20,
    cooktime = .75,
    tags = { "monstermeat" },
}
AddCookerRecipe("cookpot", monster_meatballs_recipe)
GLOBAL.STRINGS.NAMES.MONSTER_MEATBALLS = "怪物肉丸"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.MONSTER_MEATBALLS = "这玩意违反科学。"
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MONSTER_MEATBALLS = "为了生存，不得不吃下去吗？"
GLOBAL.STRINGS.CHARACTERS.WAXWELL.DESCRIBE.MONSTER_MEATBALLS = "真的不想吃这东西。"
GLOBAL.STRINGS.CHARACTERS.WENDY.DESCRIBE.MONSTER_MEATBALLS = "或许这是恶魔的杰作。"
GLOBAL.STRINGS.CHARACTERS.WICKERBOTTOM.DESCRIBE.MONSTER_MEATBALLS = "一看就是有毒的肉丸子，我最好不要吃它。"
GLOBAL.STRINGS.CHARACTERS.WILLOW.DESCRIBE.MONSTER_MEATBALLS = "依然很危险。"
GLOBAL.STRINGS.CHARACTERS.WX78.DESCRIBE.MONSTER_MEATBALLS = "这个肉丸有毒。"
GLOBAL.STRINGS.CHARACTERS.WOLFGANG.DESCRIBE.MONSTER_MEATBALLS = "这是来自地狱的杰作吗？"
GLOBAL.STRINGS.CHARACTERS.WOODIE.DESCRIBE.MONSTER_MEATBALLS = "相信我，这还是有毒的。"
GLOBAL.STRINGS.CHARACTERS.WALANI.DESCRIBE.MONSTER_MEATBALLS = "有一股恶魔的气息。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.MONSTER_MEATBALLS = "无论在加点什么佐料都没办法吃下去。"
GLOBAL.STRINGS.CHARACTERS.WOODLEGS.DESCRIBE.MONSTER_MEATBALLS = "我宁可去啃骨头。"
GLOBAL.STRINGS.CHARACTERS.WILBA.DESCRIBE.MONSTER_MEATBALLS = "哦~看起来可以试一试。"
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MONSTER_MEATBALLS = "比一开始的样子好多了。"
GLOBAL.STRINGS.CHARACTERS.WORMWOOD.DESCRIBE.MONSTER_MEATBALLS = "总感觉是有毒的。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.MONSTER_MEATBALLS = "哦，这个肉丸的色泽真是独特，我的胃可能会承受不住。"
GLOBAL.STRINGS.CHARACTERS.WHEELER.DESCRIBE.MONSTER_MEATBALLS = "探险的时候比这更糟糕的都吃过了。"


local monster_meaty_stew_recipe = {
    name = "monster_meaty_stew",
    test = function(cooker, names, tags) return tags.monster == 3 or tags.monster == 4 and not tags.inedible end,
    priority = 11,
    weight = 1,
    foodtype = "MEAT",
    health = -15,
    hunger = 170,
    perishtime = TUNING.PERISH_MED,
    sanity = -45,
    temperature = TUNING.HOT_FOOD_BONUS_TEMP,
    temperatureduration = TUNING.FOOD_TEMP_LONG,
    cooktime = .75,
    tags = { "monstermeat" },
}
AddCookerRecipe("cookpot", monster_meaty_stew_recipe)
GLOBAL.STRINGS.NAMES.MONSTER_MEATY_STEW = "怪物肉汤"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.MONSTER_MEATY_STEW = "虽然这的确可以填饱我的肚子…"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.MONSTER_MEATY_STEW = "这是一次巨大的浪费。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.MONSTER_MEATY_STEW = "用了这么多刺激的材料的肉汤一定会伤害到我的胃。"


local devil_pierogi_recipe = {
    name = "devil_pierogi",
    test = function(cooker, names, tags) return tags.monster == 1 and tags.veggie and tags.egg and not tags.inedible and not names.berries end,
    priority = 10,
    weight = 1,
    foodtype = "MEAT",
    health = 25,
    hunger = 12,
    perishtime = TUNING.PERISH_PRESERVED,
    sanity = -15,
    cooktime = 1,
    tags = { "monstermeat" },
}
AddCookerRecipe("cookpot", devil_pierogi_recipe)
GLOBAL.STRINGS.NAMES.DEVIL_PIEROGI = "地狱水饺"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.DEVIL_PIEROGI = "看起来和普通的水饺没什么差别。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.DEVIL_PIEROGI = "这是我能做到的最好的办法了。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.DEVIL_PIEROGI = "即使和别的蔬菜混合起来，我也最好不要尝试。"


local monster_kabobs_recipe = {
    name = "monster_kabobs",
    test = function(cooker, names, tags) return names.twigs == 1 and tags.monster == 1 end,
    priority = 9,
    weight = 1,
    foodtype = "MEAT",
    health = -3,
    hunger = 35,
    perishtime = TUNING.PERISH_SLOW,
    sanity = -6,
    cooktime = 2,
    tags = { "monstermeat" },
}
AddCookerRecipe("cookpot", monster_kabobs_recipe)
GLOBAL.STRINGS.NAMES.MONSTER_KABOBS = "怪物肉串"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.MONSTER_KABOBS = "至少这也是肉。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.MONSTER_KABOBS = "如果不看夹在中间的肉的话……"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.MONSTER_KABOBS = "这样搭配下来仍然有可能伤害到我的胃。"


local monster_chili_recipe = {
    name = "monster_chili",
    test = function(cooker, names, tags) return tags.monster and tags.veggie == 2 and tags.meat == 2 end,
    priority = 12,
    weight = 1,
    foodtype = "MEAT",
    health = -10,
    hunger = 37.5,
    perishtime = TUNING.PERISH_MED,
    sanity = -35,
    temperature = TUNING.HOT_FOOD_BONUS_TEMP,
    temperatureduration = TUNING.FOOD_TEMP_LONG,
    cooktime = .5,
    tags = { "monstermeat" },
}
AddCookerRecipe("cookpot", monster_chili_recipe)
GLOBAL.STRINGS.NAMES.MONSTER_CHILI = "辣椒炖怪"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.MONSTER_CHILI = "不管怎么说至少可以吃下去。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.MONSTER_CHILI = "火辣的怪物组合，颜色上看还是浪费。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.MONSTER_CHILI = "辣椒和怪肉的结合，我不该拿自己的胃去冒险。"


local blackhoney_nuggets_recipe = {
    name = "blackhoney_nuggets",
    test = function(cooker, names, tags) return names.honey and tags.monster == 1 and tags.meat <= 2 and not tags.inedible end,
    priority = 11,
    weight = 1,
    foodtype = "MEAT",
    health = 20,
    hunger = 37.5,
    perishtime = TUNING.PERISH_SLOW,
    sanity = -15,
    cooktime = 2,
    tags = { "monstermeat" }, { "honeyed" }
}
AddCookerRecipe("cookpot", blackhoney_nuggets_recipe)
GLOBAL.STRINGS.NAMES.BLACKHONEY_NUGGETS = "黑蜜肉块"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.BLACKHONEY_NUGGETS = "虽然闻着不错，但总感觉很诡异。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.BLACKHONEY_NUGGETS = "吃它的时候我会尽量不去想里面是什么。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.BLACKHONEY_NUGGETS = "这就像是化工厂的产物，我打赌我的胃会因此受伤。"


local honey_monster_ham_recipe = {
    name = "honey_monster_ham",
    test = function(cooker, names, tags) return names.honey == 1 and tags.monster == 2 and not tags.inedible end,
    priority = 11,
    weight = 1,
    foodtype = "MEAT",
    health = 25,
    hunger = 85,
    perishtime = TUNING.PERISH_SLOW,
    sanity = -30,
    temperature = TUNING.HOT_FOOD_BONUS_TEMP,
    temperatureduration = TUNING.FOOD_TEMP_AVERAGE,
    cooktime = 2,
    tags = { "monstermeat" }, { "honeyed" }
}
AddCookerRecipe("cookpot", honey_monster_ham_recipe)
GLOBAL.STRINGS.NAMES.HONEY_MONSTER_HAM = "蜜汁卤怪"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.HONEY_MONSTER_HAM = "别的都好，只有肉的色泽让我难以下咽。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.HONEY_MONSTER_HAM = "一大块不算成功的杰作，或许吧。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.HONEY_MONSTER_HAM = "这么一大块刺激的材料会对我的胃产生无法估量的伤害。"


local cobra_water_recipe = {
    name = "cobra_water",
    test = function(cooker, names, tags) return names.ice == 2 and tags.monster == 1 and names.seaweed == 1 end,
    priority = 20,
    weight = 1,
    foodtype = "GENERIC",
    health = -20,
    hunger = 1,
    sanity = -120,
    cooktime = 2,
}
AddCookerRecipe("cookpot", cobra_water_recipe)
GLOBAL.STRINGS.NAMES.COBRA_WATER = "海岛蛇草水"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.COBRA_WATER = "这是天地姐姐的最新杰作吗？"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.COBRA_WATER = "有一种城市下水道的感觉，呕。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.COBRA_WATER = "这瓶水散发出了奇怪的色泽，我要不要尝试一下？"

local surstromming = {
    name = "surstromming",
    test = function(cooker, names, tags) return (tags.fish and tags.fish >= 2) and (tags.monster and tags.monster >= 1) end,
    priority = 20,
    weight = 1,
    foodtype = "MEAT",
    health = 0,
    hunger = 200,
    sanity = -300,
    cooktime = 0.5,
	tags = { "monstermeat" },
}
AddCookerRecipe("cookpot", surstromming)
GLOBAL.STRINGS.NAMES.SURSTROMMING = "鲱鱼罐头"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.SURSTROMMING = "吃下它需要很大的勇气。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.SURSTROMMING = "我就是饿死在这里，我也绝对不吃这个！"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.SURSTROMMING = "如果我吃下这个，我的科学之旅恐怕也会就此停止。"


AddRecipe = function(p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11)
    local tmp = Recipe(p1, p2, p3, p4, p5, p6, p7, p8)
    tmp.image = p11
    tmp.atlas = p10
    return tmp
end
AddRecipe("surstromming_bomb", {
    Ingredient("surstromming", 1, "images/inventoryimages/surstromming.xml"),
    Ingredient("gunpowder", 1),
}, GLOBAL.RECIPETABS.SCIENCE, GLOBAL.TECH.NONE, nil, nil, nil, nil, nil, "images/inventoryimages/surstromming_bomb.xml", "surstromming_bomb.tex")
GLOBAL.STRINGS.NAMES.SURSTROMMING_BOMB = "鲱鱼罐头炸弹"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.SURSTROMMING_BOMB = "最危险的科技和最危险的食物的结合。"
GLOBAL.STRINGS.CHARACTERS.WARLY.DESCRIBE.SURSTROMMING_BOMB = "这是这个糟糕的北欧食品的最好的用途了。"
GLOBAL.STRINGS.CHARACTERS.WAGSTAFF.DESCRIBE.SURSTROMMING_BOMB = "所有证据都表明点燃这个炸弹可以污染方圆几十里的空气。"
GLOBAL.STRINGS.RECIPE_DESC.SURSTROMMING_BOMB = "它的威力足以媲美生化武器。"